"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkResourceRelationsType = void 0;
const param_case_1 = require("param-case");
async function checkResourceRelationsType(resourceData, entityMetadata, isDataRequired = true) {
    return Object
        .entries(resourceData.relationships)
        .reduce((accum, [key, value]) => {
        const relation = entityMetadata.relations.find(relation => relation.propertyName === key);
        if (!relation) {
            accum.push({
                source: { pointer: '/data/relationships' },
                detail: `Relation '${param_case_1.paramCase(key)}' does not exist`,
            });
            return accum;
        }
        const { relationType, propertyName } = relation;
        if (relationType === 'one-to-many') {
            accum.push({
                source: { pointer: `/data/relationships/${propertyName}` },
                detail: `Edit relation '${propertyName}' on the inverse side`,
            });
        }
        if (!isDataRequired && value.data === null) {
            return accum;
        }
        if (['one-to-one', 'many-to-one'].includes(relationType) && Array.isArray(value.data)) {
            accum.push({
                source: { pointer: `/data/relationships/${propertyName}/data` },
                detail: `Relation '${propertyName}' data definition must be an object`,
            });
        }
        if (relationType === 'many-to-many') {
            if (value.data !== null && !Array.isArray(value.data)) {
                accum.push({
                    source: { pointer: `/data/relationships/${propertyName}/data` },
                    detail: `Relation '${propertyName}' data definition must be an array`,
                });
            }
        }
        return accum;
    }, []);
}
exports.checkResourceRelationsType = checkResourceRelationsType;
//# sourceMappingURL=check-resource-relations-type.js.map