"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bodyPatchMixin = void 0;
const tslib_1 = require("tslib");
const typeorm_1 = require("@nestjs/typeorm");
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const constants_1 = require("../../../constants");
const mixin_1 = require("../../../helpers/mixin");
const helpers_1 = require("../../../helpers");
function bodyPatchMixin(entity, connectionName) {
    let BodyPatchMixin = class BodyPatchMixin {
        async transform(value) {
            const resourceMetadata = this.repository.metadata;
            const bodyErrors = await helpers_1.checkResourceBodyStructure(value, resourceMetadata, true, true);
            if (bodyErrors.length > 0) {
                throw new common_1.UnprocessableEntityException(bodyErrors);
            }
            if (this.request.params[constants_1.PARAMS_RESOURCE_ID] !== value.id) {
                throw new common_1.UnprocessableEntityException({
                    source: { pointer: '/data/id' },
                    detail: "Data 'id' must be equal to url param",
                });
            }
            const generalErrors = [];
            generalErrors.push(...await helpers_1.checkClassValidatorFields(value, resourceMetadata));
            if (!value.relationships) {
                if (generalErrors.length > 0) {
                    throw new common_1.UnprocessableEntityException(generalErrors);
                }
                return value;
            }
            generalErrors.push(...await helpers_1.checkResourceRelationsType(value, resourceMetadata, false));
            if (generalErrors.length > 0) {
                throw new common_1.UnprocessableEntityException(generalErrors);
            }
            generalErrors.push(...await helpers_1.checkResourceRelationsData(value, resourceMetadata, false));
            if (generalErrors.length > 0) {
                throw new common_1.UnprocessableEntityException(generalErrors);
            }
            return value;
        }
    };
    tslib_1.__decorate([
        typeorm_1.InjectRepository(entity, connectionName),
        tslib_1.__metadata("design:type", Object)
    ], BodyPatchMixin.prototype, "repository", void 0);
    tslib_1.__decorate([
        common_1.Inject(core_1.REQUEST),
        tslib_1.__metadata("design:type", Object)
    ], BodyPatchMixin.prototype, "request", void 0);
    BodyPatchMixin = tslib_1.__decorate([
        common_1.Injectable()
    ], BodyPatchMixin);
    return mixin_1.mixin(BodyPatchMixin);
}
exports.bodyPatchMixin = bodyPatchMixin;
//# sourceMappingURL=body-patch.js.map